@@ -2,7 +2,7 @@ package t::TestDummies::DummyStaticTools;
 use strict;
 use warnings;
 
-sub Tripler {
+sub Tripler ($){
     my ($Value) = @_;
     return $Value * 3;
 }
